redact

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 27, 2023 License: MIT Imports: 2 Imported by: 0

README

redact

Redact text

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Email

func Email(email string) string

Email redacts the part of an email before the @.

func Phone

func Phone(phone string) string

Phone redacts the last digits of a phone number.

func Word

func Word(word string) string

Word returns the first character of the word, followed by "*"s for each additional character

func WordOptions

func WordOptions(word string, prefixChars, suffixChars uint, maxAsterisk uint) string

WordOptions lets you choose how many characters to reveal at the beginning and max a

func Words

func Words(words string) string

Words redacts each word in a string.

Types

This section is empty.

Jump to