Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Word ¶
Word returns the first character of the word, followed by "*"s for each additional character
func WordOptions ¶
WordOptions lets you choose how many characters to reveal at the beginning and max a
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.